from enum import Enum

class PropertyNameEnum(Enum):
    DATE = "date"
    START_INDEX_M3 = "start_index_m3"
    END_INDEX_M3 = "end_index_m3"
    VOLUME_M3 = "volume_m3"
    ENERGY_KWH = "energy_kwh"
    CONVERTER_FACTOR = "converter_factor"
    LOCAL_TEMPERATURE = "local_temperature"
    TYPE = "type"
    TIMESTAMP = "timestamp"



import unittest

from pygazpar.client import Client

class ClientTestCase(unittest.TestCase):

    username = ""
    password = ""
    webdriver = ""
    wait_time = 30
    tmp_directory = ""

    def test_client(self):
        client = Client(self.username, self.password, self.webdriver, self.wait_time, self.tmp_directory)
        client.update()

        assert len(client.data()) != 0

if __name__ == "__main__":

    from argparse import ArgumentParser
    parser = ArgumentParser()
    parser.add_argument("-u", "--username",
                      required=True,
                      help="GRDF username (email)")    
    parser.add_argument("-p", "--password",
                      required=True,
                      help="GRDF password")    
    parser.add_argument("-w", "--webdriver",
                      required=True,
                      help="Firefox webdriver executable (geckodriver)")    
    parser.add_argument("-s", "--wait_time",
                      required=False,
                      type=int,
                      default=30,
                      help="Wait time in seconds (see https://selenium-python.readthedocs.io/waits.html for details)") 
    parser.add_argument("-t", "--tmpdir",
                      required=False,
                      default="/tmp",
                      help="tmp directory (default is /tmp)") 
  
    args = parser.parse_args()

    ClientTestCase.username = args.username
    ClientTestCase.password = args.password
    ClientTestCase.webdriver = args.webdriver
    ClientTestCase.wait_time = args.wait_time
    ClientTestCase.tmp_directory = args.tmpdir

    unittest.main()


import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
  name = 'pygazpar',
  version = '0.1.10',
  author = 'Stephane Senart',
  author_email = 'stephane.senart@gmail.com',
  description = 'Retrieve gas consumption from GrDF web site (French Gas Company)',
  long_description=long_description,
  long_description_content_type="text/markdown",
  url = 'https://github.com/ssenart/PyGazpar',
  packages=setuptools.find_packages(),
  classifiers=[
    'Development Status :: 3 - Alpha',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package    'Intended Audience :: Developers',      # Define that your audience are developers
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',
    'Operating System :: OS Independent',    
    'Programming Language :: Python :: 3.7',    
  ],
  python_requires='>=3.7',
  download_url = 'https://github.com/ssenart/pygazpar/releases/tag/0.1.9',
  keywords = ['Energy', 'Natural Gas', 'Consumption', 'GrDF', 'Gazpar' ],
  entry_points={
    'console_scripts': [
        'pygazpar = pygazpar.__main__:main'
    ]
  },
  install_requires=[
    'selenium == 3.141',
    'openpyxl == 2.6.3'
  ],
  license='MIT',
)




import argparse
import sys
import json
import traceback

from pygazpar.client import Client

def main():
    """Main function"""
    parser = argparse.ArgumentParser()
    parser.add_argument("-u", "--username",
                      required=True,
                      help="GRDF username (email)")    
    parser.add_argument("-p", "--password",
                      required=True,
                      help="GRDF password")    
    parser.add_argument("-w", "--webdriver",
                      required=True,
                      help="Firefox webdriver executable (geckodriver)")    
    parser.add_argument("-s", "--wait_time",
                      required=False,
                      type=int,
                      default=30,
                      help="Wait time in seconds (see https://selenium-python.readthedocs.io/waits.html for details)")    
    parser.add_argument("-t", "--tmpdir",
                      required=False,
                      default="/tmp",
                      help="tmp directory (default is /tmp)")    

    args = parser.parse_args()

    client = Client(args.username, args.password, args.webdriver, args.wait_time, args.tmpdir)

    try:
        client.update()
    except BaseException:
        print('An error occured while querying PyGazpar library : %s', traceback.format_exc())
        return 1

    print(json.dumps(client.data(), indent=2))

if __name__ == '__main__':
    sys.exit(main())
